@@ -8,8 +8,14 @@
 ##'   (i.e. in "npc" \link[grid]{unit}s)
 ##' @param warn should a warning be issued if no point is within the specified
 ##'   tolerance? See also details.
+##' @importFrom grid convertX convertY grid.locator grid.circle gpar 
+##' @importFrom lattice trellis.focus ltext
 map.identify <- function (object, model = spc ~ x * y, voronoi = FALSE, ...,
                           tol = .02, warn = TRUE){
+	
+	if (! interactive ())
+		stop ("map.identify works only on interactive graphics devices.")
+	
   chk.hy (object)
   validObject (object)
 
