@@ -4,7 +4,7 @@
 ##' @title Spectra plotting with ggplot2
 ##' @param x hyperSpec object
 ##' @param wl.range wavelength ranges to plot
-##' @param \dots handed to \code{\link[ggplot2]{geom_line}}
+##' @param ... handed to \code{\link[ggplot2]{geom_line}}
 ##' @param mapping see  \code{\link[ggplot2]{geom_line}}
 ##' @param spc.nmax maximum number of spectra to plot
 ##' @param map.lineonly if \code{TRUE}, \code{mapping} will be handed to
@@ -34,7 +34,6 @@ qplotspc <- function (x,
                       map.lineonly = FALSE){
   chk.hy (x)
   validObject (x)
-  require (ggplot2)
   
   ## cut away everything that isn't asked for _before_ transforming to data.frame
   if (nrow (x) > spc.nmax) {
@@ -83,7 +82,7 @@ qplotspc <- function (x,
 ##' @title Spectra plotting with ggplot2
 ##' @param object  hyperSpec object
 ##' @param mapping see  \code{\link[ggplot2]{geom_tile}}
-##' @param \dots handed to \code{\link[ggplot2]{geom_tile}}
+##' @param ... handed to \code{\link[ggplot2]{geom_tile}}
 ##' @param func function to summarize the wavelengths
 ##' @param func.args arguments to \code{func}
 ##' @param map.tileonly if \code{TRUE}, \code{mapping} will be handed to
@@ -105,7 +104,6 @@ qplotmap <- function (object, mapping = aes_string (x = "x", y = "y", fill = "sp
                       map.tileonly = FALSE){
   chk.hy (object)
   validObject (object)
-  require (ggplot2)
 
   if (nwl (object) > 1 & ! is.null (func))
     object <- do.call (apply, c (list (object, 1, func), func.args))
@@ -152,7 +150,7 @@ qplotmap <- function (object, mapping = aes_string (x = "x", y = "y", fill = "sp
 ##' @title Spectra plotting with ggplot2
 ##' @param object hyperSpec object
 ##' @param mapping see  \code{\link[ggplot2]{geom_point}}
-##' @param \dots handed to \code{\link[ggplot2]{geom_point}}
+##' @param ... handed to \code{\link[ggplot2]{geom_point}}
 ##' @export 
 ##' @param func function to summarize the wavelengths, if \code{NULL}, only the first wavelength is used
 ##' @param func.args arguments to \code{func}
@@ -171,7 +169,6 @@ qplotc <- function (object, mapping = aes_string(x = "c", y = "spc"), ...,
                     map.pointonly = FALSE){
   chk.hy (object)
   validObject (object)
-  require (ggplot2)
 
   dots <- list (...)
 
