@@ -19,8 +19,6 @@
 
 split.line <- function (x, separator, trim.blank = TRUE) {
   tmp <- regexpr (separator, x)
-  #if (length (tmp) == 1 && tmp [[1]] == -1)
-  #  warning ("line without separator", separator)
 
   key   <- substr (x, 1, tmp - 1)
   value <- substr (x, tmp + 1, nchar (x))
@@ -41,7 +39,7 @@ split.line <- function (x, separator, trim.blank = TRUE) {
 ### some ENVI-specific helper functions .............................................................
 
 
-.read.ENVI.header  <- function (file, headerfilename) {
+.find.ENVI.header  <- function (file, headerfilename) {
   if (is.null (headerfilename)) {
     headerfilename <- paste (dirname (file), sub ("[.][^.]+$", ".*", basename (file)), sep = "/")
     tmp <- Sys.glob (headerfilename)
@@ -50,19 +48,19 @@ split.line <- function (x, separator, trim.blank = TRUE) {
     if (length (headerfilename) > 1) {
       headerfilename <- headerfilename [grepl ("[.][hH][dD][rR]$", headerfilename)]
       if (length (headerfilename == 1))
-        message ("Guessing header file name ", headerfilename)
+        message (".read.ENVI.header: Guessing header file name ", headerfilename)
     }
     
     if (length (headerfilename) != 1)
       stop ("Cannot guess header file name")
     else
-      cat (".read.ENVI.header: Guessing header file name (", headerfilename, ")\n", sep = '')
+      message (".read.ENVI.header: Guessing header file name ", headerfilename)
   }
     
   if (!file.exists(headerfilename)) 
     stop("Could not open header file: ", headerfilename)
 
-  readLines (headerfilename)
+  headerfilename
 }
 
 # ...................................................................................................
@@ -125,14 +123,14 @@ split.line <- function (x, separator, trim.blank = TRUE) {
 
   if (is.null (header$`byte order`)){
     header$`byte order` <- .Platform$endian
-    message (".read.ENVI.bin: 'byte order' not given or incorrect. Guessing '",
+    message (".read.ENVI.bin: 'byte order' not given => Guessing '",
              .Platform$endian, "'\n", sep = '')
   }
   if (! header$`byte order` %in% c ("big", "little", "swap")) {
     header$`byte order` <- as.numeric (header$`byte order`)
     if (! header$`byte order` %in% 0 : 1) {
       header$`byte order` <- .Platform$endian
-      warning ("byte order not given or incorrect. Guessing '", .Platform$endian, "'")
+      warning ("byte order incorrect. Guessing '", .Platform$endian, "'")
     } else if (header$`byte order` == 0)
       header$`byte order` <- "little"
     else 
@@ -254,7 +252,7 @@ split.line <- function (x, separator, trim.blank = TRUE) {
 ##' @param header list with the respective information, see details.
 ##' @param x,y vectors of form c(offset, step size) for the position vectors,
 ##'   see details.
-##' @param wavelength,label,log lists that overwrite the respective information
+##' @param wavelength,label lists that overwrite the respective information
 ##'   from the ENVI header file. These data is then handed to
 ##'   \code{\link[hyperSpec]{initialize}}
 ##' @param keys.hdr2data determines which fields of the header file should be put into the extra
@@ -262,7 +260,6 @@ split.line <- function (x, separator, trim.blank = TRUE) {
 ##' 
 ##' To specify certain entries, give character vectors containing the lowercase
 ##'   names of the header file entries.
-##' @param keys.hdr2log deprecated
 ##' @return a \code{hyperSpec} object
 ##' @author C. Beleites, testing for the Nicolet files C. Dicko
 ##' @seealso \code{\link[caTools]{read.ENVI}}
@@ -278,9 +275,9 @@ split.line <- function (x, separator, trim.blank = TRUE) {
 ##' @keywords IO file
 read.ENVI <- function (file = stop ("read.ENVI: file name needed"), headerfile = NULL, 
 							  header = list (), 
-							  keys.hdr2data = FALSE, keys.hdr2log = FALSE,
-                       x = 0 : 1, y = x, 
-                       wavelength = NULL, label = list (), log = list ()) {
+							  keys.hdr2data = FALSE, 
+							  x = 0 : 1, y = x, 
+							  wavelength = NULL, label = list ()) {
   force (y)
 
   if (! file.exists (file))
@@ -291,8 +288,11 @@ read.ENVI <- function (file = stop ("read.ENVI: file name needed"), headerfile =
       stop ("header must be a list of parameters. Did you mean headerfile instead?")
     else
       stop ("header must be a list of parameters.")
-						  
-  tmp <- .read.ENVI.header (file, headerfile)
+				
+  if (is.null (headerfile))
+  	headerfile <- .find.ENVI.header (file, headerfile)
+  
+  tmp <- readLines (headerfile)
   tmp <- .read.ENVI.split.header (tmp)
   header <- modifyList (tmp, header)  
 
@@ -315,18 +315,9 @@ read.ENVI <- function (file = stop ("read.ENVI: file name needed"), headerfile =
   x <- rep (seq (0, header$samples - 1), each = header$lines)   * x [2] + x [1]
   y <- rep (seq (0, header$lines   - 1),        header$samples) * y [2] + y [1]
   
-  ## header lines => extra data columns or log entries
+  ## header lines => extra data columns 
   extra.data <- header [keys.hdr2data]
 
-  if (hy.getOption ("log")){
-    log <- modifyList (list (short = "read.ENVI", 
-                             long = list (call = match.call (),
-                               header = getbynames (header, keys.hdr2log))),
-                       log)
-  } else {
-      log = NULL
-  }
-
   if (.options$gc) gc ()
   
   if (length (extra.data) > 0) {
@@ -339,7 +330,9 @@ read.ENVI <- function (file = stop ("read.ENVI: file name needed"), headerfile =
   if (.options$gc) gc ()
 
   ## finally put together the hyperSpec object
-  new ("hyperSpec", data = data, spc = spc,
-       wavelength = wavelength, labels = label, log = log)
+  spc <- new ("hyperSpec", data = data, spc = spc, wavelength = wavelength, labels = label)
+  
+  ## consistent file import behaviour across import functions
+  .fileio.optional (spc, file)
 }
 
