@@ -18,7 +18,6 @@
 ##'   If \code{NULL}, a \code{hyperSpec} object containing the polynomial
 ##'   coefficients rather than evaluted baselines is returned.
 ##' @param poly.order order of the polynomial to be used
-##' @param short,user,date handed to \code{logentry}
 ##' @return \code{hyperspec} object containing the baselines in the spectra
 ##'   matrix, either as polynomial coefficients or as polynomials evaluted on
 ##'   the spectral range of \code{apply.to}
@@ -33,8 +32,7 @@
 ##' baselines <- spc.fit.poly(chondro[,, c (625 ~ 640, 1785 ~ 1800)], chondro)
 ##' plot(chondro - baselines, "spcprctl5")
 ##' 
-spc.fit.poly <- function (fit.to, apply.to = NULL, poly.order = 1,
-                          short = "spc.fit.poly", user = NULL, date = NULL){
+spc.fit.poly <- function (fit.to, apply.to = NULL, poly.order = 1){
   chk.hy (fit.to)
   if (! is.null (apply.to))
     chk.hy (apply.to)
@@ -44,9 +42,8 @@ spc.fit.poly <- function (fit.to, apply.to = NULL, poly.order = 1,
 
   x <- fit.to@wavelength
   x <- outer(x, 0 : poly.order, "^")             # Vandermonde matrix of x
-  if (is.null (short)) short <- "spc.fit.poly: coefficients" 
-  p <- apply (fit.to, 1, function (y, x){qr.solve (x, y)}, x,
-              short = short, user = user, date = date)
+  
+  p <- apply (fit.to, 1, function (y, x){qr.solve (x, y)}, x)
 
   if (is.null (apply.to)){
     colnames (p@data$spc) <- paste ("x^", 0 : poly.order, sep="")
@@ -56,11 +53,6 @@ spc.fit.poly <- function (fit.to, apply.to = NULL, poly.order = 1,
     wl <- apply.to@wavelength;
     x <- outer(wl, 0 : poly.order, "^")             # Vandermonde matrix of x
     apply.to@data$spc <- I (t (apply (p[[]], 1, function (p, x) {x %*% p}, x)))
-    if (is.null (short)) short <- "spc.fit.poly: spectra" 
-    apply.to <- .logentry (apply.to, short = short,
-                           long = list (apply = match.call()$apply, poly.order = poly.order),
-                           user = user, date = date)
-
 
     .wl(apply.to) <- wl
     colnames (apply.to@data$spc) <- format (wl, digits = 4)
@@ -85,9 +77,7 @@ spc.fit.poly <- function (fit.to, apply.to = NULL, poly.order = 1,
 ##' plot(chondro - baselines, "spcprctl5")
 ##' 
 spc.fit.poly.below <- function (fit.to, apply.to = fit.to, poly.order = 1,
-                                npts.min = NULL, noise = 0,
-                                short = "spc.fit.poly.below", user = NULL,
-                                date = NULL){
+                                npts.min = NULL, noise = 0){
   chk.hy (fit.to)
   if (! is.null (apply.to))
     chk.hy (apply.to)
@@ -129,10 +119,8 @@ spc.fit.poly.below <- function (fit.to, apply.to = fit.to, poly.order = 1,
     colnames (fit.to@data$spc) <- paste ("x^", 0 : poly.order, sep="")
 
     validObject (fit.to)
-    .logentry (fit.to, short = short,
-               long = list (apply = NULL, poly.order = poly.order,
-                 npts.min = npts.min, noise = noise),
-               user = user, date = date)
+    
+    fit.to
   } else {
     x <- apply.to@wavelength
 
@@ -144,9 +132,7 @@ spc.fit.poly.below <- function (fit.to, apply.to = fit.to, poly.order = 1,
     colnames (apply.to@data$spc) <- format (x, digits = 4)
 
     validObject (apply.to)
-    .logentry (apply.to, short = short,
-               long = list (apply = match.call()$apply, poly.order = poly.order,
-                 npts.min = npts.min, noise = noise),
-               user = user, date = date)
+    
+    apply.to
   }
 }
